@@ -1178,7 +1178,8 @@ lookup_uri (GnomeVFSURI     *uri,
 										&in_args, sizeof (in_args), 
 										&out_args, sizeof (out_args));
 					LOCK_SAMBA();
-					if (!res) {
+					if (res == FALSE) {
+						res = GNOME_VFS_ERROR_ACCESS_DENIED;
 						break;
 					} else if (out_args.username == NULL) {
 						res = GNOME_VFS_ERROR_ACCESS_DENIED;
@@ -1201,7 +1202,7 @@ lookup_uri (GnomeVFSURI     *uri,
 			g_free (user);
 			g_free (password);
 			
-			if (res) {
+			if (res != GNOME_VFS_OK) {
 				(*file)->u.share.connection = NULL;
 				g_free (*path_remainder);
 				return res;
